@@ -6,17 +6,19 @@ import sys
 import time
 import warnings
 
-from DisplayCAL import config
-from DisplayCAL import localization as lang
+from DisplayCAL import (
+    config,
+    localization as lang,
+)
 from DisplayCAL.config import (
     defaults,
     enc,
-    getcfg,
-    geticon,
     get_argyll_display_number,
     get_default_dpi,
     get_display_number,
     get_display_rects,
+    getcfg,
+    geticon,
     scale_adjustment_factor,
     setcfg,
     writecfg,
@@ -26,6 +28,9 @@ from DisplayCAL.meta import name as appname
 from DisplayCAL.options import debug
 from DisplayCAL.util_list import floatlist, strlist
 from DisplayCAL.wxaddons import wx
+from DisplayCAL.wxfixes import (
+    GenBitmapButton as BitmapButton,
+)
 from DisplayCAL.wxwindows import (
     BaseApp,
     BitmapBackgroundPanel,
@@ -33,7 +38,6 @@ from DisplayCAL.wxwindows import (
     InfoDialog,
     InvincibleFrame,
 )
-from DisplayCAL.wxfixes import GenBitmapButton as BitmapButton
 
 try:
     from DisplayCAL import RealDisplaySizeMM as RDSMM
@@ -218,9 +222,7 @@ class MeasureFrame(InvincibleFrame):
         self.hsizer.Add(
             self.zoomnormalbutton, flag=wx.ALIGN_CENTER | wx.TOP | wx.BOTTOM, border=10
         )
-        self.zoomnormalbutton.SetToolTipString(
-            lang.getstr("measureframe." "zoomnormal")
-        )
+        self.zoomnormalbutton.SetToolTipString(lang.getstr("measureframe.zoomnormal"))
 
         self.hsizer.Add((8, 0))
 
@@ -240,8 +242,19 @@ class MeasureFrame(InvincibleFrame):
         )
         self.zoomoutbutton.SetToolTipString(lang.getstr("measureframe.zoomout"))
 
-        if os.getenv("XDG_SESSION_TYPE") != "wayland":
+        if os.getenv("XDG_SESSION_TYPE") == "wayland":
             # No manual centering under Wayland...
+            self.centermsg = wx.StaticText(
+                self.panel,
+                -1,
+                lang.getstr("measureframe.center.manual"),
+                style=wx.ALIGN_CENTER_HORIZONTAL,
+            )
+            self.centermsg.Wrap(self.hsizer.MinSize[0] - 20)
+            self.sizer.Add(
+                self.centermsg, flag=wx.ALIGN_CENTER | wx.LEFT | wx.RIGHT, border=10
+            )
+        else:
             self.centerbutton = BitmapButton(
                 self.panel,
                 -1,
@@ -255,17 +268,6 @@ class MeasureFrame(InvincibleFrame):
                 self.centerbutton, flag=wx.ALIGN_CENTER | wx.LEFT | wx.RIGHT, border=10
             )
             self.centerbutton.SetToolTipString(lang.getstr("measureframe.center"))
-        else:
-            self.centermsg = wx.StaticText(
-                self.panel,
-                -1,
-                lang.getstr("measureframe.center.manual"),
-                style=wx.ALIGN_CENTER_HORIZONTAL,
-            )
-            self.centermsg.Wrap(self.hsizer.MinSize[0] - 20)
-            self.sizer.Add(
-                self.centermsg, flag=wx.ALIGN_CENTER | wx.LEFT | wx.RIGHT, border=10
-            )
 
         self.vsizer = wx.BoxSizer(wx.VERTICAL)
         self.sizer.Add(self.vsizer, flag=wx.ALIGN_BOTTOM | wx.ALIGN_CENTER_HORIZONTAL)
@@ -424,9 +426,9 @@ class MeasureFrame(InvincibleFrame):
                 scale = cur_scale
         scale = min(scale, 50.0)  # Argyll max
         if debug:
-            print(" x:", x)
-            print(" y:", y)
-            print(" scale:", scale)
+            print("[D]  x:", x)
+            print("[D]  y:", y)
+            print("[D]  scale:", scale)
             print("[D]  scale_adjustment_factor:", scale_adjustment_factor)
         scale /= float(scale_adjustment_factor)
         if debug:
